@@ -1,24 +1,8 @@
-# noqa: D400 D205
-"""
-computer_graphics_demo
-======================
-
-Common functions.
-"""
+"""Computer graphics algorithms demonstration."""
 import taichi as ti
 from typing import Final
 
-try:
-    from get_version import get_version, NoVersionFound
-
-    try:
-        __version__ = get_version(__file__)
-    except NoVersionFound:
-        __version__ = "0.0.0"
-except ImportError:
-    __version__ = "0.0.0"
-
-_binname: Final = "cgdemo"
+VERSION: Final = "0.0.1"
 pixels = ti.Vector.field(3, float)
 
 
