@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.circle
-=============================
-
-Draw a circle.
-"""
+"""Computer graphics algorithms demonstration."""
 from .. import setpixel
 
 
