@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.circle.bresenham
-=======================================
-
-Bresenham algorithm.
-"""
+"""Computer graphics algorithms demonstration."""
 import taichi as ti
 from . import set8pixel
 
