@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.fill
-===========================
-
-Fill a region.
-"""
+"""Computer graphics algorithms demonstration."""
 import copy
 
 
