@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.fill.seed
-================================
-
-Seed point algorithm.
-"""
+"""Computer graphics algorithms demonstration."""
 from ..line import polygon
 from ..line.bresenham import line
 from .. import pixels, setpixel
