@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.julia
-============================
-
-Draw a Julia set.
-"""
+"""Computer graphics algorithms demonstration."""
 import taichi as ti
 from . import pixels, setpixel
 
