@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.koch
-===========================
-
-Draw a Koch curve
-"""
+"""Computer graphics algorithms demonstration."""
 import math
 from .line.bresenham import line
 
