@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.line
-===========================
-
-Draw a line.
-"""
+"""Computer graphics algorithms demonstration."""
 from ..fill import cycle_shift
 from .. import setpixel
 from typing import Callable, Optional
