@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.line.bresenham
-=====================================
-
-Bresenham algorithm.
-"""
+"""Computer graphics algorithms demonstration."""
 import taichi as ti
 from .. import setpixel
 from . import polygon
