@@ -1,9 +1,4 @@
-"""
-computer_graphics_demo.mandelbrot
-=================================
-
-Draw a Mandelbrot set
-"""
+"""Computer graphics algorithms demonstration."""
 import taichi as ti
 from . import pixels, setpixel
 
